@@ -31,7 +31,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QDialog>
-#include <kwidgetsaddons_version.h>
 
 #include <KConfigGroup>
 #include <QDir>
@@ -153,21 +152,13 @@ void MetalinkHttp::slotSignatureVerified()
         }
 
         if (brokenFiles.count()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (KMessageBox::warningTwoActionsList(nullptr,
-#else
-            if (KMessageBox::warningYesNoList(nullptr,
-#endif
                                                    i18n("The download could not be verified, try to repair it?"),
                                                    brokenFiles,
                                                    QString(),
                                                    KGuiItem(i18nc("@action:button", "Repair")),
                                                    KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 == KMessageBox::PrimaryAction) {
-#else
-                == KMessageBox::Yes) {
-#endif
                 if (repair()) {
                     KGet::addTransfer(m_metalinkxmlUrl);
                     // TODO Use a Notification instead. Check kget.h for how to use it.
@@ -218,7 +209,7 @@ bool MetalinkHttp::metalinkHttpInit()
         qDebug() << "data source factory being deleted";
         delete dataFactory;
     } else {
-        QHashIterator<QString, QString> itr(m_DigestList);
+        QMultiHashIterator<QString, QString> itr(m_DigestList);
         while (itr.hasNext()) {
             itr.next();
             qDebug() << itr.key() << ":" << itr.value();
@@ -295,7 +286,7 @@ void MetalinkHttp::setDigests()
         const QString digestType = MetalinkHttp::adaptDigestType(digest.left(eqDelimiter).trimmed());
         const QString hexDigestValue = base64ToHex(digest.mid(eqDelimiter + 1).trimmed());
 
-        m_DigestList.insertMulti(digestType, hexDigestValue);
+        m_DigestList.insert(digestType, hexDigestValue);
     }
 }
 
